<?php
/*
Plugin Name: QuickPanel Push Notifications
Plugin URI: https://www.quickpanel.in/wp-plugin/
Description: Easily integrate QuickPanel Web Push Notifications with your WordPress site. Upload and manage the QuickPanel JavaScript file directly from the WordPress dashboard.
Version: 1.0.0
Author: Amit Das
Author URI: https://www.amitdas.site
License: GPLv2 or later
*/

// Prevent direct access to the file
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * Enqueue the QuickPanel Pixel Code in the site's head.
 */
function qp_enqueue_custom_pixel_code() {
    $qp_pixel_id = get_option('qp_pixel_id'); // Retrieve the Pixel ID from settings

    if (!empty($qp_pixel_id)) {
        // Construct the pixel code using the Pixel ID
        $url = esc_url("https://www.quickpanel.in/pixel/$qp_pixel_id");
        $final_pixel_code = "<!-- Pixel Code - https://www.quickpanel.in/ -->\n" .
                            "<script defer src=\"$url\"></script>\n" .
                            "<!-- END Pixel Code -->";
        echo $final_pixel_code; // Output the final pixel code
    }
}
add_action('wp_head', 'qp_enqueue_custom_pixel_code');

/**
 * Enqueue custom styles for the QuickPanel admin page.
 */
function qp_enqueue_custom_admin_styles() {
    echo '
    <style>
        /* General styling for the admin wrapper */
        .wrap {
            background-color: #f9f9f9; /* Light background for contrast */
            padding: 20px; /* Adjusted padding for better spacing */
            border: 1px solid #e1e1e1; /* Softer border color */
            border-radius: 8px; /* Rounded corners */
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1); /* More prominent shadow */
        }

        /* Container for main content */
        .qp-container {
            max-width: 90%; /* Maximum width set to 90% for better fluidity */
            margin: 0 auto; /* Center align */
            padding: 20px; /* Padding inside the container */
            background-color: white; /* White background for the container */
            border-radius: 8px; /* Rounded corners */
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1); /* Subtle shadow */
        }

        /* Header styling */
        .qp-header {
            background-color: #d14836; /* Header color */
            padding: 15px; /* Reduced padding for better fit */
            color: white;
            text-align: center;
            border-radius: 8px 8px 0 0; /* Rounded top corners */
        }
        .qp-header img {
            max-height: 50px; /* Reduced logo size for better fit on small screens */
            width: auto; /* Maintain aspect ratio */
            height: auto; /* Maintain aspect ratio */
        }

        /* Warning box styling */
        .qp-warning {
            background-color: #ffe4e1; /* Softer warning color */
            padding: 10px; /* Adjusted padding */
            margin: 15px 0; /* Reduced margins */
            border-left: 5px solid #d14836; /* Left border color */
            border-radius: 4px; /* Rounded corners */
            color: #d14836;
            font-weight: 600; /* Slightly bolder text */
            font-size: 14px; /* Reduced font size for better readability */
        }

        /* Navigation tabs styling */
        .nav-tab-wrapper {
            margin-bottom: 15px; /* Adjusted margin */
            border-bottom: 2px solid #0073aa; /* Bottom border for tabs */
        }
        .nav-tab {
            padding: 8px 12px; /* Adjusted padding for tabs */
            margin-right: 5px; /* Space between tabs */
            border-radius: 4px; /* Rounded corners */
            transition: background-color 0.3s ease; /* Smooth hover transition */
            font-weight: 500; /* Regular weight for tab text */
            color: #333; /* Darker text color */
            font-size: 14px; /* Font size for tabs */
        }
        .nav-tab-active {
            background-color: #0073aa;
            color: white;
            font-weight: bold; /* Bold text for active tab */
        }
        .nav-tab:hover {
            background-color: #005177; /* Darker shade on hover */
            color: white; /* White text on hover */
        }

        /* Button styling */
        .button-primary {
            background-color: #0073aa;
            border-color: #006799;
            text-decoration: none;
            color: white;
            border-radius: 4px; /* Rounded button corners */
            padding: 10px 15px; /* Adjusted button padding */
            transition: background-color 0.3s ease; /* Smooth hover transition */
            font-size: 14px; /* Smaller font for buttons */
            cursor: pointer; /* Pointer cursor for buttons */
            display: inline-block; /* Ensure button behaves like a block */
        }
        .button-primary:hover {
            background-color: #005177; /* Darker shade on hover */
        }

        /* Troubleshooting box styling */
        .qp-troubleshooting {
            border: 1px solid #dcdcdc; /* Lighter border color */
            padding: 10px; /* Adjusted padding */
            margin-top: 15px; /* Reduced margin */
            border-radius: 4px; /* Rounded corners */
            background-color: #fafafa; /* Light background */
        }
        .qp-troubleshooting h2 {
            font-size: 18px; /* Adjusted font size for headings */
            font-weight: 600; /* Bold weight for headings */
            margin-bottom: 10px; /* Space below headings */
            color: #333; /* Darker color for headings */
        }

        /* Input field styling */
        input[type="text"] {
            width: 100%; /* Full width input */
            padding: 10px; /* Adjusted padding */
            border: 1px solid #ccc; /* Border color */
            border-radius: 4px; /* Rounded corners */
            margin-top: 5px; /* Space above input */
            transition: border-color 0.3s ease; /* Smooth border color transition */
            font-size: 14px; /* Font size for input */
        }
        input[type="text"]:focus {
            border-color: #0073aa; /* Change border color on focus */
            outline: none; /* Remove default outline */
        }

        /* Responsive styling */
        @media (max-width: 768px) {
            .qp-container {
                padding: 15px; /* Reduce padding on smaller screens */
            }
            .nav-tab {
                padding: 8px; /* Adjust tab padding for smaller screens */
                font-size: 12px; /* Smaller font size for tabs */
            }
            .button-primary {
                padding: 8px; /* Adjust button padding for smaller screens */
                font-size: 12px; /* Smaller font size for buttons */
            }
            .qp-warning, .qp-troubleshooting {
                font-size: 12px; /* Smaller font size for warnings */
            }
        }

        @media (max-width: 480px) {
            .qp-header img {
                max-height: 40px; /* Further reduce logo size on very small screens */
            }
            input[type="text"] {
                font-size: 12px; /* Smaller font size for inputs */
            }
        }
    </style>
    ';
}
add_action('admin_head', 'qp_enqueue_custom_admin_styles');

/**
 * Create admin menu for QuickPanel settings.
 */
function qp_create_admin_menu() {
    add_menu_page(
        __('QuickPanel Push Notifications', 'quickpanel'),
        __('QuickPanel Push', 'quickpanel'),
        'manage_options',
        'quickpanel-main-menu',
        'qp_main_menu_page',
        'dashicons-bell',
        100
    );
}
add_action('admin_menu', 'qp_create_admin_menu');

/**
 * Check if QuickPanel Setup is incomplete.
 *
 * @return bool True if setup is incomplete, false otherwise.
 */
function is_quickpanel_setup_incomplete() {
    $pixel_id = get_option('qp_pixel_id'); // Retrieve the Pixel ID
    $upload_dir = ABSPATH;
    $file_path = $upload_dir . 'quickpanel_push.js'; // Path to the JavaScript file

    // Return true if either Pixel ID is missing or the JS file does not exist
    return empty($pixel_id) || !file_exists($file_path);
}

/**
 * Main menu page with Setup and Configuration tabs.
 */
function qp_main_menu_page() {
    $primary_tab = isset($_GET['primary_tab']) ? $_GET['primary_tab'] : 'setup';

    ?>
    <div class="wrap">
        <!-- Container for main content -->
        <div class="qp-container">
            <!-- Header Section with Centered Logo -->
            <div class="qp-header">
                <a href="https://www.quickpanel.in" target="_blank">
                    <img src="https://www.quickpanel.in/uploads/main/020799a13c785b94cd09b2192688c29c.png" alt="QuickPanel Logo">
                </a>
            </div>

            <?php
            // Display warning if setup is incomplete
            if (is_quickpanel_setup_incomplete()) {
                ?>
                <div class="qp-warning">
                    <strong><?php esc_html_e('QuickPanel Setup Incomplete', 'quickpanel'); ?>:</strong> 
                    <?php esc_html_e('Please enter your QuickPanel Pixel ID to begin sending push notifications.', 'quickpanel'); ?>
                </div>
                <?php
            }
            ?>

            <!-- Primary Tabs: Setup and Configuration -->
            <h2 class="nav-tab-wrapper">
                <a href="?page=quickpanel-main-menu&primary_tab=setup" class="nav-tab <?php echo $primary_tab === 'setup' ? 'nav-tab-active' : ''; ?>">
                    <?php esc_html_e('Setup', 'quickpanel'); ?>
                </a>
                <a href="?page=quickpanel-main-menu&primary_tab=configuration" class="nav-tab <?php echo $primary_tab === 'configuration' ? 'nav-tab-active' : ''; ?>">
                    <?php esc_html_e('Configuration', 'quickpanel'); ?>
                </a>
            </h2>

            <?php
            // Show Setup content if "Setup" is selected
            if ($primary_tab === 'setup') {
                // Include the setup guide file
                include plugin_dir_path(__FILE__) . 'quickpanel-setup.php';

                // Display the Send Notifications form directly after the setup
                qp_send_notifications_page();
                
                // Add space between Send Notifications and Settings sections
                echo '<div style="margin: 30px 0;"></div>'; // Spacing

            // Show Configuration (without secondary tabs)
            } else {
                // Display the settings form directly
                ?>
                <form method="post" action="options.php">
                    <?php
                    settings_fields('qp_settings_group');
                    do_settings_sections('quickpanel-settings');
                    submit_button();
                    ?>
                </form>
                <hr>
                <h2><?php esc_html_e('Upload or Manage JavaScript File (quickpanel_push.js)', 'quickpanel'); ?></h2>
                <?php qp_js_file_upload_section(); ?>
                <?php
            }
            ?>
        </div>
    </div>
    <?php
}

/**
 * Register QuickPanel settings.
 */
function qp_register_settings() {
    register_setting('qp_settings_group', 'qp_pixel_id', 'sanitize_text_field');
    add_settings_section('qp_main_section', __('QuickPanel Settings', 'quickpanel'), 'qp_section_text', 'quickpanel-settings');
    add_settings_field('qp_pixel_id', __('QuickPanel Pixel ID', 'quickpanel'), 'qp_pixel_id_field', 'quickpanel-settings', 'qp_main_section');
}
add_action('admin_init', 'qp_register_settings');

/**
 * Render the settings section text.
 */
function qp_section_text() {
    echo '<p>' . __('Enter your QuickPanel Pixel ID below:', 'quickpanel') . '</p>';
}

/**
 * Render the QuickPanel Pixel ID input field.
 */
function qp_pixel_id_field() {
    $pixel_id = get_option('qp_pixel_id');
    echo "<input type='text' name='qp_pixel_id' value='" . esc_attr($pixel_id) . "' style='width: 100%;' />"; // Use 100% width for better responsiveness

    // Show success message after saving settings
    if (isset($_GET['settings-updated']) && $_GET['settings-updated'] === 'true') {
        echo '<p style="color: green;">' . esc_html__('Pixel ID saved successfully.', 'quickpanel') . '</p>';
    }
}

/**
 * Handle JavaScript file upload and deletion section.
 */
function qp_js_file_upload_section() {
    $upload_dir = ABSPATH;
    $file_path = $upload_dir . 'quickpanel_push.js'; // Upload to the root directory

    if (file_exists($file_path)) {
        echo '<p><strong>' . esc_html__('quickpanel_push.js', 'quickpanel') . '</strong> ' . esc_html__('already exists in the root directory.', 'quickpanel') . '</p>';
        echo '<form method="post">';
        wp_nonce_field('qp_delete_js_file', 'qp_delete_js_nonce');
        echo '<input type="hidden" name="qp_delete_file" value="1" />';
        submit_button(__('Delete quickpanel_push.js', 'quickpanel'), 'delete');
        echo '</form>';
        qp_handle_file_delete();
    } else {
        echo '<form method="post" enctype="multipart/form-data">';
        wp_nonce_field('qp_upload_js_file', 'qp_upload_js_nonce');
        echo '<input type="file" name="qp_js_file" accept=".js" />';
        submit_button(__('Upload JS File', 'quickpanel'));
        echo '</form>';
        
        // Handle the upload here to reflect changes immediately
        qp_handle_file_upload(); 
    }
}

/**
 * Handle JavaScript file upload.
 */
function qp_handle_file_upload() {
    if (isset($_FILES['qp_js_file']) && !empty($_FILES['qp_js_file']['name'])) {
        if (!isset($_POST['qp_upload_js_nonce']) || !wp_verify_nonce($_POST['qp_upload_js_nonce'], 'qp_upload_js_file')) {
            echo '<p style="color: red;">' . esc_html__('Security check failed.', 'quickpanel') . '</p>';
            return;
        }

        $uploaded_file = $_FILES['qp_js_file'];
        $file_type = wp_check_filetype($uploaded_file['name']);

        // Validate file type
        if ($file_type['ext'] !== 'js') {
            echo '<p style="color: red;">' . esc_html__('Only JavaScript (.js) files are allowed.', 'quickpanel') . '</p>';
            return;
        }

        $upload_dir = ABSPATH;
        $target_path = $upload_dir . 'quickpanel_push.js';

        // Move the uploaded file to the target path
        if (move_uploaded_file($uploaded_file['tmp_name'], $target_path)) {
            echo '<p style="color: green;">' . esc_html__('File uploaded successfully as quickpanel_push.js.', 'quickpanel') . '</p>';

            // Only extract the Pixel ID if it is not already set
            $pixel_id = get_option('qp_pixel_id');
            if (empty($pixel_id)) {
                // Extract the Pixel ID from the uploaded file
                $js_content = file_get_contents($target_path);
                if (preg_match("/let website_pixel_key = '([^']+)';/", $js_content, $matches)) {
                    $pixel_id = $matches[1]; // Assign the found Pixel ID
                    update_option('qp_pixel_id', $pixel_id); // Save it to the database
                    echo '<p style="color: green;">' . esc_html__('Pixel ID updated from uploaded file.', 'quickpanel') . '</p>';
                }
            }

            // Reload the page to show the delete option
            echo '<script>location.reload();</script>';
        } else {
            echo '<p style="color: red;">' . esc_html__('There was an error uploading the file.', 'quickpanel') . '</p>';
        }
    }
}

/**
 * Handle JavaScript file deletion.
 */
function qp_handle_file_delete() {
    if (isset($_POST['qp_delete_file']) && $_POST['qp_delete_file'] == 1) {
        if (!isset($_POST['qp_delete_js_nonce']) || !wp_verify_nonce($_POST['qp_delete_js_nonce'], 'qp_delete_js_file')) {
            echo '<p style="color: red;">' . esc_html__('Security check failed.', 'quickpanel') . '</p>';
            return;
        }

        $upload_dir = ABSPATH;
        $file_path = $upload_dir . 'quickpanel_push.js';

        // Delete the file if it exists
        if (file_exists($file_path)) {
            if (unlink($file_path)) {
                echo '<p style="color: green;">' . esc_html__('File quickpanel_push.js deleted successfully.', 'quickpanel') . '</p>';
                echo '<script>location.reload();</script>'; // Reload the page
            } else {
                echo '<p style="color: red;">' . esc_html__('There was an error deleting the file.', 'quickpanel') . '</p>';
            }
        }
    }
}

/**
 * Display the Send Notifications page.
 */
function qp_send_notifications_page() {
    ?>
    <div class="wrap">
        <h2><?php esc_html_e('Send Notifications via QuickPanel', 'quickpanel'); ?></h2>
        <p><?php esc_html_e('You can send notifications by logging in to QuickPanel:', 'quickpanel'); ?></p>
        <a href="https://www.quickpanel.in/campaigns" class="button button-primary" target="_blank"><?php esc_html_e('Send Notification!', 'quickpanel'); ?></a>
    </div>
    <?php
}
