<?php
/**
 * QuickPanel Setup Guide Page
 */

function qp_setup_guide() {
    ?>
    <style>
        .wrap {
            padding: 20px; /* Adjusted padding for better spacing */
            background-color: #f9f9f9; /* Light background */
            border: 1px solid #e1e1e1; /* Softer border color */
            border-radius: 8px; /* Rounded corners */
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1); /* Subtle shadow */
        }
        .wrap h1 {
            color: #333;
            font-size: 26px;
            font-weight: bold;
            margin-bottom: 15px;
            text-align: center;
        }
        .wrap p {
            font-size: 16px;
            color: #666;
            margin-bottom: 15px;
            line-height: 1.6;
        }
        .wrap ol {
            padding-left: 40px;
            margin: 25px 0;
            list-style-type: decimal;
        }
        .wrap ol li {
            margin-bottom: 12px;
            font-size: 16px;
            color: #444;
            line-height: 1.6;
        }
        .qp-troubleshooting {
            margin-top: 35px;
            padding: 20px;
            background-color: #e7f4f9; /* Light background for troubleshooting */
            border: 1px solid #c1e0eb; /* Border color */
            border-radius: 6px; /* Rounded corners */
        }
        .qp-troubleshooting h2 {
            color: #005780;
            font-size: 20px;
            margin-bottom: 12px;
        }
        .qp-troubleshooting p {
            color: #555;
            font-size: 15px;
        }
        .wrap a {
            color: #005780;
            font-weight: 500;
            text-decoration: none;
            border-bottom: 1px solid transparent;
            transition: all 0.3s ease;
        }
        .wrap a:hover {
            border-bottom: 1px solid #005780;
        }
        /* Button Styles */
        .button-custom {
            background-color: #0073aa; /* Button background color */
            color: White; /* Button text color */
            padding: 8px 20px;
            border-radius: 5px;
            text-decoration: none;
            font-size: 15px;
            font-weight: bold;
            border: none;
            cursor: pointer;
            transition: background-color 0.3s ease;
        }
        .button-custom:hover {
            background-color: #005780; /* Button hover color */
        }
        /* Specific style for the header button */
        .qp-header .button-custom {
            color: white; /* Ensuring the header button text color is white */
        }

        /* Responsive styling */
        @media (max-width: 768px) {
            .wrap {
                padding: 15px; /* Reduce padding on smaller screens */
            }
            .wrap h1 {
                font-size: 24px; /* Adjusted heading size */
            }
            .wrap p, .wrap ol li {
                font-size: 14px; /* Adjusted font size for better readability */
            }
        }

        @media (max-width: 480px) {
            .wrap h1 {
                font-size: 22px; /* Further adjusted heading size */
            }
            .qp-troubleshooting h2 {
                font-size: 18px; /* Adjusted heading size for troubleshooting */
            }
            .wrap p, .wrap ol li {
                font-size: 12px; /* Smaller font size for inputs */
            }
            .button-custom {
                font-size: 14px; /* Smaller font size for buttons */
            }
        }
    </style>
    <div class="wrap">
        <h1><?php esc_html_e('QuickPanel Web Push Setup Guide', 'quickpanel'); ?></h1>
        <p><?php esc_html_e('Follow these steps to integrate Web Push notifications into your WordPress blog:', 'quickpanel'); ?></p>

        <ol>
            <li>
                <?php esc_html_e('Create a', 'quickpanel'); ?>
                <a href="https://www.quickpanel.in" target="_blank"><?php esc_html_e('QuickPanel', 'quickpanel'); ?></a>
                <?php esc_html_e('account or log in to your existing account.', 'quickpanel'); ?>
            </li>
            <li>
                <?php esc_html_e('Create a Web Push app in QuickPanel by following the instructions in our', 'quickpanel'); ?>
                <a href="https://www.quickpanel.in/blog/how-to-add-push-notifications-to-wordpress-with-quickpanel" target="_blank"><?php esc_html_e('Web Push Quickstart Guide', 'quickpanel'); ?></a>.
            </li>
            <li>
                <?php esc_html_e('Set up your Web Push app using QuickPanel\'s Web Push Editor.', 'quickpanel'); ?>
            </li>
        </ol>

        <div class="qp-troubleshooting">
            <h2><?php esc_html_e('Troubleshooting', 'quickpanel'); ?></h2>
            <p><?php esc_html_e('If you encounter any issues, you can refer to our complete Setup Guide for step-by-step instructions.', 'quickpanel'); ?></p>
            <p><?php esc_html_e('Need further help? Feel free to reach out via', 'quickpanel'); ?>
               <a href="mailto:support@quickpanel.in"><?php esc_html_e('email', 'quickpanel'); ?></a>.
            </p>
        </div>
    </div>
    <?php
}

qp_setup_guide();
